==> geant4.9.6.p02.tar.gz: geant4.9.6.p02/examples/.doxygen/Doxymodules_field.h <==
// $Id: Doxymodules_field.h 60059 2012-06-27 13:00:49Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_field.h
/// \brief The page that defines the extended/field examples modules 


/** @defgroup extended_field field
 *  Extended examples field classes
 *  @{
 */

/** @defgroup extended_field_BlineTracer BlineTracer
 *  Field example BlineTracer
 *  @ingroup extended_field
 *  @{
 */

  class G4BlineEquation {};
  class G4BlineEventAction {};
  class G4BlinePrimaryGeneratorAction {};
  class G4BlineSteppingAction {};
  class G4BlineTracer {};
  class G4BlineTracerMessenger {};

/** @} */

/** @defgroup extended_field_field01 field01 
 *  Field example field01
 *  @{
 */

  class F01CalorHit {};
  class F01CalorimeterSD {};
  class F01DetectorConstruction {};
  class F01DetectorMessenger {};
  class F01EventAction {};
  class F01EventActionMessenger {};
  class F01FieldMessenger {};
  class F01FieldSetup {};
  class F01PhysicsList {};
  class F01PhysicsListMessenger {};
  class F01PrimaryGeneratorAction {};
  class F01PrimaryGeneratorMessenger {};
  class F01RunAction {};
  class F01RunMessenger {};
  class F01StepCut {};
  class F01SteppingAction {};
  class F01SteppingMessenger {};
  class F01SteppingVerbose {};

/** @} */

/** @defgroup extended_field_field02 field02 
 *  Field example field02
 *  @{
 */

  class F02CalorHit {};
  class F02CalorimeterSD {};
  class F02DetectorConstruction {};
  class F02DetectorMessenger {};
  class F02ElectricFieldSetup {};
  class F02EventAction {};
  class F02EventActionMessenger {};
  class F02FieldMessenger {};
  class F02PhysicsList {};
  class F02PhysicsListMessenger {};
  class F02PrimaryGeneratorAction {};
  class F02PrimaryGeneratorMessenger {};
  class F02RunAction {};
  class F02RunMessenger {};
  class F02StepCut {};
  class F02SteppingAction {};
  class F02SteppingMessenger {};
  class F02SteppingVerbose {};

/** @} */

/** @defgroup extended_field_field03 field03 
 *  Field example field03
 *  @{
 */

  class F03CalorHit {};
  class F03CalorimeterSD {};
  class F03DetectorConstruction {};
  class F03DetectorMessenger {};
  class F03EventAction {};
  class F03EventActionMessenger {};
  class F03FieldMessenger {};
  class F03FieldSetup {};
  class F03PhysicsList {};
  class F03PhysicsListMessenger {};
  class F03PrimaryGeneratorAction {};
  class F03PrimaryGeneratorMessenger {};
  class F03RunAction {};
  class F03RunMessenger {};
  class F03StepCut {};
  class F03SteppingAction {};
  class F03SteppingMessenger {};
  class F03SteppingVerbose {};

/** @} */

/** @defgroup extended_field_field04 field04 
 *  Field example field04
 *  @{
 */

  class F04DetectorConstruction {};
  class F04DetectorMessenger {};
  class F04ElementField {};
  class F04EventAction {};
  class F04EventActionMessenger {};
  class F04ExtraPhysics {};
  class F04FieldMessenger {};
  class F04FocusSolenoid {};
  class F04GlobalField {};
  class F04Materials {};
  class F04OpticalPhysics {};
  class F04PhysicsList {};
  class F04PhysicsListMessenger {};
  class F04PrimaryGeneratorAction {};
  class F04PrimaryGeneratorMessenger {};
  class F04RunAction {};
  class F04RunActionMessenger {};
  class F04SimpleSolenoid {};
  class F04StackingAction {};
  class F04StepMax {};
  class F04SteppingAction {};
  class F04SteppingActionMessenger {};
  class F04SteppingVerbose {};
  class F04TrackingAction {};
  class F04Trajectory {};
  class F04TrajectoryPoint {};
  class F04UserTrackInformation {};

/** @} */

/** @defgroup extended_field_field05 field05 
 *  Field example field05
 *  @{
 */

  class F05DetectorConstruction {};
  class F05ExtraPhysics {};
  class F05Field {};
  class F05PhysicsList {};
  class F05PrimaryGeneratorAction {};
  class F05SteppingAction {};

/** @} */

/** @defgroup extended_field_field06 field06 
 *  Field example field06
 *  @{
 */

  class F06DetectorConstruction {};
  class F06EventAction {};
  class F06EventActionMessenger {};
  class F06ExtraPhysics {};
  class F06Field {};
  class F06PhysicsList {};
  class F06PrimaryGeneratorAction {};

/** @} */

/** @} */

==> geant4.10.00.p04.tar.gz: geant4.10.00.p04/examples/.doxygen/Doxymodules_field.h <==
// $Id: Doxymodules_field.h 76473 2013-11-11 10:35:14Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_field.h
/// \brief The page that defines the extended/field examples modules 


/** @defgroup extended_field field
 *  Extended examples field classes
 *  @{
 */

/** @defgroup extended_field_BlineTracer BlineTracer
 *  Field example BlineTracer
 *  @ingroup extended_field
 *  @{
 */

  class G4BlineEquation {};
  class G4BlineEventAction {};
  class G4BlinePrimaryGeneratorAction {};
  class G4BlineSteppingAction {};
  class G4BlineTracer {};
  class G4BlineTracerMessenger {};

/** @} */

/** @defgroup extended_field_field01 field01 
 *  Field example field01
 *  @{
 */

  class F01ActionInitialization {};
  class F01CalorHit {};
  class F01CalorimeterSD {};
  class F01DetectorConstruction {};
  class F01DetectorMessenger {};
  class F01EventAction {};
  class F01EventActionMessenger {};
  class F01FieldMessenger {};
  class F01FieldSetup {};
  class F01PhysicsList {};
  class F01PhysicsListMessenger {};
  class F01PrimaryGeneratorAction {};
  class F01PrimaryGeneratorMessenger {};
  class F01RunAction {};
  class F01RunMessenger {};
  class F01StepCut {};
  class F01SteppingVerbose {};

/** @} */

/** @defgroup extended_field_field02 field02 
 *  Field example field02
 *  @{
 */

  class F02ActionInitialization {};
  class F02CalorHit {};
  class F02CalorimeterSD {};
  class F02DetectorConstruction {};
  class F02DetectorMessenger {};
  class F02ElectricFieldSetup {};
  class F02EventAction {};
  class F02EventActionMessenger {};
  class F02FieldMessenger {};
  class F02PhysicsList {};
  class F02PhysicsListMessenger {};
  class F02PrimaryGeneratorAction {};
  class F02PrimaryGeneratorMessenger {};
  class F02RunAction {};
  class F02RunMessenger {};
  class F02StepCut {};
  class F02SteppingVerbose {};

/** @} */

/** @defgroup extended_field_field03 field03 
 *  Field example field03
 *  @{
 */

  class F03CalorHit {};
  class F03CalorimeterSD {};
  class F03DetectorConstruction {};
  class F03DetectorMessenger {};
  class F03EventAction {};
  class F03EventActionMessenger {};
  class F03FieldMessenger {};
  class F03FieldSetup {};
  class F03PhysicsList {};
  class F03PhysicsListMessenger {};
  class F03PrimaryGeneratorAction {};
  class F03PrimaryGeneratorMessenger {};
  class F03RunAction {};
  class F03RunMessenger {};
  class F03StepCut {};
  class F03SteppingVerbose {};

/** @} */

/** @defgroup extended_field_field04 field04 
 *  Field example field04
 *  @{
 */

  class F04DetectorConstruction {};
  class F04DetectorMessenger {};
  class F04ElementField {};
  class F04EventAction {};
  class F04EventActionMessenger {};
  class F04ExtraPhysics {};
  class F04FieldMessenger {};
  class F04FocusSolenoid {};
  class F04GlobalField {};
  class F04Materials {};
  class F04OpticalPhysics {};
  class F04PhysicsList {};
  class F04PhysicsListMessenger {};
  class F04PrimaryGeneratorAction {};
  class F04PrimaryGeneratorMessenger {};
  class F04RunAction {};
  class F04RunActionMessenger {};
  class F04SimpleSolenoid {};
  class F04StackingAction {};
  class F04StepMax {};
  class F04SteppingAction {};
  class F04SteppingActionMessenger {};
  class F04SteppingVerbose {};
  class F04TrackingAction {};
  class F04Trajectory {};
  class F04TrajectoryPoint {};
  class F04UserTrackInformation {};

/** @} */

/** @defgroup extended_field_field05 field05 
 *  Field example field05
 *  @{
 */

  class F05ActionInitialization {};
  class F05DetectorConstruction {};
  class F05ExtraPhysics {};
  class F05Field {};
  class F05PhysicsList {};
  class F05PrimaryGeneratorAction {};
  class F05SteppingAction {};
  class F05SteppingVerbose {};

/** @} */

/** @defgroup extended_field_field06 field06 
 *  Field example field06
 *  @{
 */

  class F06ActionInitialization {};
  class F06DetectorConstruction {};
  class F06ExtraPhysics {};
  class F06PhysicsList {};
  class F06PrimaryGeneratorAction {};

/** @} */

/** @} */
